@@ -4,15 +4,21 @@ import sys
 import subprocess
 import zipfile
 
-from StringIO import StringIO
-
 import Image
 
 from xml.etree import cElementTree as et
 
-from ConfigParser import ConfigParser
 import optparse
 
+import six
+from six import BytesIO
+from six import u
+from six.moves import configparser
+
+if not six.PY3:
+    def next(i):
+        return i.next()
+
 try:
     from os.path import relpath
 except ImportError:
@@ -144,9 +150,9 @@ class RstFile(object):
     def _add_image(self, fname, fcontent, width=None, height=None):
         if fname.endswith('.wmf'):
             try:
-                stream = StringIO(fcontent)
+                stream = BytesIO(fcontent)
                 i = Image.open(stream)
-                stream = StringIO()
+                stream = BytesIO()
                 i.save(stream, 'PNG')
                 fcontent = stream.getvalue()
                 fname = fname[:-4] + '.png'
@@ -168,7 +174,7 @@ class RstFile(object):
     def insert_rows_spanned_cells(self):
         row = self.current_table[-1]
         if len(self.current_table) > 1:
-            for i in xrange(len(row), len(self.current_table[0])):
+            for i in range(len(row), len(self.current_table[0])):
                 last_line_i = -2
                 separators = 0
                 if self.current_table[last_line_i] == 'separator':
@@ -193,7 +199,7 @@ class RstFile(object):
         row = self.current_table[-1]
         row.append((self.current, columns_span, rows_span))
 
-        for i in xrange(1, columns_span):
+        for i in range(1, columns_span):
             row.append((None, columns_span - i, rows_span))
 
         self.insert_rows_spanned_cells()
@@ -274,7 +280,7 @@ class RstFile(object):
         next_border_char = '-'
 
         for row_i, row in enumerate(rendered_cells):
-            for line_i in xrange(0, row_heights[row_i]):
+            for line_i in range(0, row_heights[row_i]):
                 line = '| '
                 for cell_i, cell in enumerate(row):
                     if cell[0] is not None and len(cell[0]) > line_i:
@@ -333,7 +339,7 @@ class RstFile(object):
 
         output = self.lines
         self.lines = lines
-        return u'\n'.join(output)
+        return u('\n').join(output)
 
 
 class SphinxWriter(object):
@@ -381,7 +387,7 @@ class SphinxWriter(object):
             self.current_file.directive('toctree', maxdepth=2)
         self.current_file = RstFile()
         fname = text.replace(' ', '').replace('/', '').replace(':', '_')
-        fname = fname.encode('ascii', 'ignore')
+        fname = fname.encode('ascii', 'ignore').decode()
         self.files[fname] = self.current_file
 
         self.files['index'].append(fname)
@@ -453,12 +459,12 @@ class SphinxWriter(object):
                 f = codecs.open(fname, 'w', 'utf8')
                 f.write(content)
                 f.close()
-                print "Done"
+                print("Done")
             else:
-                print "No change"
+                print("No change")
 
             if rstfile.images:
-                print "Saving images..."
+                print("Saving images...")
             for fname, attrs in rstfile.images.items():
                 fname = os.path.join(self.dir, 'images', fname)
                 fcontent = attrs['content']
@@ -591,7 +597,7 @@ class ODTReader(object):
                 self.style_map[key] = 'warning'
             if display_name.lower() in ('tip', 'trucs & astuces'):
                 self.style_map[key] = 'tip'
-        print self.style_map
+        print(self.style_map)
 
     def call_visitor(self, trigger, *args, **kw):
         cb = getattr(self.visitor, trigger, None)
@@ -647,7 +653,7 @@ class ODTReader(object):
             href = href[2:]
         if href.startswith('../'):
             fcontent = open(
-                os.path.join(self.dirname, href[3:]), 'r').read()
+                os.path.join(self.dirname, href[3:]), mode='rb').read()
         else:
             fcontent = self.archive.read(href)
         return fname, fcontent
@@ -747,7 +753,7 @@ class ODTReader(object):
             self.__it = self.iterate()
 
         try:
-            i, count = self.__it.next()
+            i, count = next(self.__it)
         except StopIteration:
             self.done = True
 
@@ -955,7 +961,7 @@ def main():
     elif len(args) == 1:
         configname = os.path.abspath(args[0])
         configdir = os.path.dirname(configname)
-        config = ConfigParser()
+        config = configparser.ConfigParser()
         config.read(configname)
         for section in config.sections():
             filename = config.has_option(section, 'filename') and \
@@ -966,7 +972,7 @@ def main():
                 config.get(section, 'targetdir') or '.'
             targetdir = os.path.normpath(
                 os.path.join(configdir, targetdir))
-            print "Converting %s in %s" % (filename, targetdir)
+            print("Converting %s in %s" % (filename, targetdir))
             convert_odt(filename, targetdir, debug=options.debug,
                 options={'download_source_link': options.download_source_link})
 
